# Link Database Tools

Package provides tools that allow to filter databases produced by https://github.com/rumca-js/Django-link-archive.

Can filter or analyze entries from https://github.com/rumca-js/Internet-Places-Database.

# Tools

 - DbAnalyzer - provides analysis of the DB contents
 - Db2Feeds - converts database to DB of feeds
 - Db2JSON - converts database to JSON
 - DbFilter - filters database (only bookmarks? only votes?)

# Installation

pip install linkarchivetools
